@@ -15,12 +15,15 @@
 #
 
 
-import sys
 import os.path as op
-from os import rename, remove, makedirs
-from .alert_actions_merge import merge_conf_file
+import sys
+from os import makedirs, remove
 
-from splunk_add_on_ucc_framework.alert_utils.alert_utils_common.conf_parser import TABConfigParser
+from splunk_add_on_ucc_framework.alert_utils.alert_utils_common.conf_parser import (
+    TABConfigParser,
+)
+
+from .alert_actions_merge import merge_conf_file
 
 
 def write_file(file_name, file_path, content, logger, merge="stanza_overwrite"):
